@@ -1,10 +1,8 @@
 package fluentd
 
 import (
-	"bytes"
 	"fmt"
 	"sort"
-	"strings"
 	"text/template"
 
 	logforward "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1alpha1"
@@ -18,10 +16,11 @@ type ConfigGenerator struct {
 	*generators.Generator
 	includeLegacyForwardConfig bool
 	includeLegacySyslogConfig  bool
+	useOldRemoteSyslogPlugin   bool
 }
 
 //NewConfigGenerator creates an instance of FluentdConfigGenerator
-func NewConfigGenerator(includeLegacyForwardConfig, includeLegacySyslogConfig bool) (*ConfigGenerator, error) {
+func NewConfigGenerator(includeLegacyForwardConfig, includeLegacySyslogConfig, useOldRemoteSyslogPlugin bool) (*ConfigGenerator, error) {
 	engine, err := generators.New("OutputLabelConf",
 		&template.FuncMap{
 			"labelName":           labelName,
@@ -31,66 +30,37 @@ func NewConfigGenerator(includeLegacyForwardConfig, includeLegacySyslogConfig bo
 	if err != nil {
 		return nil, err
 	}
-	return &ConfigGenerator{engine, includeLegacyForwardConfig, includeLegacySyslogConfig}, nil
+	return &ConfigGenerator{engine, includeLegacyForwardConfig, includeLegacySyslogConfig, useOldRemoteSyslogPlugin}, nil
 }
 
 //Generate the fluent.conf file using the forwarding information
 func (engine *ConfigGenerator) Generate(forwarding *logforward.ForwardingSpec) (string, error) {
-
+	logger.DebugObject("Generating fluent.conf using %s", forwarding)
 	//sanitize here
-	var (
-		logTypes               sets.String
-		sourceInputLabels      []string
-		pipelineNames          map[logforward.LogSourceType][]string
-		sourceToPipelineLabels []string
-		pipelineToOutputLabels []string
-		outputLabels           []string
-		err                    error
-	)
+	var sourceInputLabels []string
+	var sourceToPipelineLabels []string
+	var pipelineToOutputLabels []string
+	var outputLabels []string
+	var err error
 
-	// Provide logTypes for legacy forwarding protocols w/o a user-provided
-	// LogFowarding instance to enable logTypes for template generation.
-	if engine.includeLegacyForwardConfig || engine.includeLegacySyslogConfig {
-		logTypes = sets.NewString(
-			string(logforward.LogSourceTypeApp),
-			string(logforward.LogSourceTypeAudit),
-			string(logforward.LogSourceTypeInfra),
-		)
-		pipelineNames = map[logforward.LogSourceType][]string{
-			logforward.LogSourceTypeApp:   {},
-			logforward.LogSourceTypeAudit: {},
-			logforward.LogSourceTypeInfra: {},
-		}
-	} else {
-		logTypes = gatherLogSourceTypes(forwarding.Pipelines)
-		pipelineNames = mapSourceTypesToPipelineNames(forwarding.Pipelines)
-	}
+	logTypes, appNs := gatherLogSourceTypes(forwarding.Pipelines)
 
-	sourceInputLabels, err = engine.generateSource(logTypes)
-	if err != nil {
+	if sourceInputLabels, err = engine.generateSource(logTypes, appNs); err != nil {
+		logger.Tracef("Error generating source blocks: %v", err)
 		return "", err
 	}
-
-	sourceToPipelineLabels, err = engine.generateSourceToPipelineLabels(pipelineNames)
-	if err != nil {
+	if sourceToPipelineLabels, err = engine.generateSourceToPipelineLabels(mapSourceTypesToPipelineNames(forwarding.Pipelines)); err != nil {
+		logger.Tracef("Error generating source to pipeline blocks: %v", err)
 		return "", err
 	}
 	sort.Strings(sourceToPipelineLabels)
-
-	// Omit generation for missing pipelines, i.e. legacy methods don't provide any
-	if len(forwarding.Pipelines) > 0 {
-		pipelineToOutputLabels, err = engine.generatePipelineToOutputLabels(forwarding.Pipelines)
-		if err != nil {
-			return "", err
-		}
+	if pipelineToOutputLabels, err = engine.generatePipelineToOutputLabels(forwarding.Pipelines); err != nil {
+		logger.Tracef("Error generating pipeline to output labels blocks: %v", err)
+		return "", err
 	}
-
-	// Omit generation for missing outputs, i.e. legacy methods provide them via configmap
-	if len(forwarding.Outputs) > 0 {
-		outputLabels, err = engine.generateOutputLabelBlocks(forwarding.Outputs)
-		if err != nil {
-			return "", err
-		}
+	if outputLabels, err = engine.generateOutputLabelBlocks(forwarding.Outputs); err != nil {
+		logger.Tracef("Error generating to output label blocks: %v", err)
+		return "", err
 	}
 
 	data := struct {
@@ -116,17 +86,23 @@ func (engine *ConfigGenerator) Generate(forwarding *logforward.ForwardingSpec) (
 	}
 	result, err := engine.Execute("fluentConf", data)
 	if err != nil {
+		logger.Tracef("Error generating fluentConf")
 		return "", fmt.Errorf("Error processing fluentConf template: %v", err)
 	}
-	return pretty(result), nil
+	logger.Tracef("Successfully generated fluent.conf: %v", result)
+	return result, nil
 }
 
-func gatherLogSourceTypes(pipelines []logforward.PipelineSpec) sets.String {
+func gatherLogSourceTypes(pipelines []logforward.PipelineSpec) (sets.String, sets.String) {
 	types := sets.NewString()
+	appNamespaces := sets.NewString()
 	for _, pipeline := range pipelines {
 		types.Insert(string(pipeline.SourceType))
+		if pipeline.SourceType == logforward.LogSourceTypeApp {
+			appNamespaces.Insert(pipeline.Namespaces...)
+		}
 	}
-	return types
+	return types, appNamespaces
 }
 
 func mapSourceTypesToPipelineNames(pipelines []logforward.PipelineSpec) map[logforward.LogSourceType][]string {
@@ -142,31 +118,6 @@ func mapSourceTypesToPipelineNames(pipelines []logforward.PipelineSpec) map[logf
 	return result
 }
 
-func pretty(in string) string {
-	stack := -1
-	out := bytes.NewBufferString("")
-	for _, line := range strings.Split(in, "\n") {
-		stack = prettyLine(out, line, stack)
-	}
-	return out.String()
-}
-func prettyLine(out *bytes.Buffer, in string, levelIn int) int {
-	levelOut := levelIn
-	trimmed := strings.Trim(in, " \t")
-	if strings.HasPrefix(trimmed, "</") {
-		levelOut = levelIn - 1
-	} else if strings.HasPrefix(trimmed, "<") && !strings.HasPrefix(trimmed, "</") {
-		levelOut = levelIn + 1
-	}
-
-	for i := 0; i < levelOut; i++ {
-		out.WriteString("\t")
-	}
-	out.WriteString(trimmed)
-	out.WriteString("\n")
-	return levelOut
-}
-
 //generateSourceToPipelineLabels generates fluentd label stanzas to fan source types to multiple pipelines
 func (engine *ConfigGenerator) generateSourceToPipelineLabels(sourcesToPipelines map[logforward.LogSourceType][]string) ([]string, error) {
 	configs := []string{}
@@ -235,6 +186,13 @@ func (engine *ConfigGenerator) generateOutputLabelBlocks(outputs []logforward.Ou
 		case logforward.OutputTypeForward:
 			storeTemplateName = "forward"
 			outputTemplateName = "outputLabelConfNoCopy"
+		case logforward.OutputTypeSyslog:
+			if engine.useOldRemoteSyslogPlugin {
+				storeTemplateName = "storeSyslogOld"
+			} else {
+				storeTemplateName = "storeSyslog"
+			}
+			outputTemplateName = "outputLabelConfNoRetry"
 		default:
 			logger.Warnf("Pipeline targets include an unrecognized type: %q", output.Type)
 			continue
