@@ -15,15 +15,16 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 
 	k8shandler "github.com/openshift/cluster-logging-operator/pkg/k8shandler"
+	"github.com/openshift/cluster-logging-operator/pkg/k8shandler/indexmanagement"
 	"github.com/openshift/cluster-logging-operator/pkg/logger"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
 	elasticsearch "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
 )
 
 const (
-	InfraIndexPrefix          = ".operations."
-	ProjectIndexPrefix        = "project."
-	AuditIndexPrefix          = ".audit."
+	InfraIndexPrefix          = "infra-"
+	ProjectIndexPrefix        = "app-"
+	AuditIndexPrefix          = "audit-"
 	elasticsearchesLoggingURI = "apis/logging.openshift.io/v1/namespaces/openshift-logging/elasticsearches"
 )
 
@@ -87,6 +88,10 @@ type ElasticLogStore struct {
 	Framework *E2ETestFramework
 }
 
+func (es *ElasticLogStore) ApplicationLogs(timeToWait time.Duration) (string, error) {
+	panic("Method not implemented")
+}
+
 func (es *ElasticLogStore) HasInfraStructureLogs(timeToWait time.Duration) (bool, error) {
 	err := wait.Poll(defaultRetryInterval, timeToWait, func() (done bool, err error) {
 		errorCount := 0
@@ -132,6 +137,10 @@ func (es *ElasticLogStore) HasAuditLogs(timeToWait time.Duration) (bool, error)
 	return true, err
 }
 
+func (es *ElasticLogStore) GrepLogs(expr string, timeToWait time.Duration) (string, error) {
+	return "Not Found", fmt.Errorf("Not implemented")
+}
+
 //Indices fetches the list of indices stored by Elasticsearch
 func (es *ElasticLogStore) Indices() (Indices, error) {
 	options := metav1.ListOptions{
@@ -202,6 +211,7 @@ func (tc *E2ETestFramework) DeployAnElasticsearchCluster(pwd string) (cr *elasti
 			Nodes:            []elasticsearch.ElasticsearchNode{node},
 			ManagementState:  elasticsearch.ManagementStateManaged,
 			RedundancyPolicy: elasticsearch.ZeroRedundancy,
+			IndexManagement:  indexmanagement.NewSpec(nil),
 		},
 	}
 	tc.AddCleanup(func() error {
